@@ -119,6 +119,7 @@ CONFIG = [
     ("post_auto_excerpt", 1, True),
     ("post_redirect_refresh", 5, True),
     ("post_always_section", False, True),
+    ("post_show_prev_next", True, True),
     ("disqus_shortname", None, True),
     ("disqus_drafts", False, True),
     ("disqus_pages", False, True),
@@ -435,8 +436,11 @@ class Post(BlogPageMixin):
             else:
                 doctree.append(deepcopy)
         else:
+            excerpt_container = nodes.container()
+            excerpt_container.attributes["classes"].append("ablog-post-excerpt")
             for node in self.excerpt:
-                doctree.append(node.deepcopy())
+                excerpt_container.append(node.deepcopy())
+            doctree.append(excerpt_container)
         app = self._blog.app
         revise_pending_xrefs(doctree, pagename)
         app.env.resolve_references(doctree, pagename, app.builder)
